@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 #
 #  Copyright (C) 2008, 2016, 2020  Smithsonian Astrophysical Observatory
 #
@@ -19,14 +18,16 @@ from __future__ import absolute_import
 #
 
 import logging
+
 import numpy
-from ._utils import arf_fold, do_group, expand_grouped_mask, \
-    filter_resp, is_in, resp_init, rmf_fold, shrink_effarea
-from ._pileup import apply_pileup
 
 from sherpa.utils import get_position, filter_bins
 from sherpa.utils.err import IOErr, DataErr
 
+from ._utils import arf_fold, do_group, expand_grouped_mask, \
+    filter_resp, is_in, resp_init, rmf_fold, shrink_effarea
+from ._pileup import apply_pileup
+
 
 __all__ = ['arf_fold', 'rmf_fold', 'do_group', 'apply_pileup',
            'eqwidth', 'calc_photon_flux', 'calc_energy_flux',
@@ -41,16 +42,6 @@ __all__ = ['arf_fold', 'rmf_fold', 'do_group', 'apply_pileup',
 warning = logging.getLogger(__name__).warning
 
 
-try:
-    from ._region import Region, region_mask
-
-    __all__.append('region_mask')
-    __all__.append('Region')
-
-except ImportError:
-    warning('failed to import sherpa.astro.utils._region; Region routines ' +
-            'will not be available')
-
 # Useful constants
 #
 _hc = 12.39841874  # nist.gov in [keV-Angstrom]
