@@ -1,5 +1,5 @@
 //  Copyright (C) 2007, 2015-2018, 2019, 2020
-//                Smithsonian Astrophysical Observatory
+//      Smithsonian Astrophysical Observatory
 //
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -118,6 +118,10 @@ void agnsed_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 void qsosed_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
 
+#ifdef XSPEC_12_11_0
+void agnslim_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
+#endif
+
 #ifndef XSPEC_12_9_1
 void xsaped_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xsbape_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -138,7 +142,7 @@ void c6pmekl_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 void c6pvmkl_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void c6vmekl_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void cemekl_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void compbb_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void compls_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -147,7 +151,7 @@ void xstitg_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 void disk_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void diskir_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xsdskb_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
-#ifndef XSPEC_12_10_1  
+#ifndef XSPEC_12_10_1
 void xsdili_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
 void diskm_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -159,7 +163,7 @@ void ezdiskbb_(float* ear, int* ne, float* param, int* ifl, float* photar, float
 
 #ifndef XSPEC_12_9_1
 void xsgaul_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
-#endif  
+#endif
 
 void grad_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 
@@ -169,7 +173,7 @@ void xsgrbcomp(const double* energy, int nFlux, const double* params, int spectr
 
 void jet_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void xsgrbm_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void spin_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 
@@ -182,7 +186,7 @@ void xslorz_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 void xsmeka_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xsmekl_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void nsa_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void nsagrav_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void nsatmos_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -190,7 +194,7 @@ void nsatmos_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 #ifndef XSPEC_12_10_0
 void nsmax_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void xspegp_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xsp1tr_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xsposm_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -198,12 +202,12 @@ void xsposm_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 #ifndef XSPEC_12_9_1
 void xsrays_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void xredge_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xsrefsch_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void srcut_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void sresc_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
-#ifdef XSPEC_12_10_0  
+#ifdef XSPEC_12_10_0
 void ssa_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
 void xsstep_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -211,25 +215,25 @@ void xsstep_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 #ifndef XSPEC_12_9_1
 void xsvape_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void xsbrmv_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 
 #ifndef XSPEC_12_9_1
 void xsvmek_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xsvmkl_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 #ifndef XSPEC_12_9_1
 void xsvrys_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void xszbod_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xszbrm_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 
-#ifndef XSPEC_12_10_0  
+#ifndef XSPEC_12_10_0
 void acisabs_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void xscnst_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xscabs_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xscycl_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -248,10 +252,10 @@ void xssmdg_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 void xsspln_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xssssi_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 
-#ifndef XSPEC_12_10_0  
+#ifndef XSPEC_12_10_0
 void swind1_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void xsred_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xsabsv_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xsvphb_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -267,7 +271,7 @@ void xszphb_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 #ifndef XSPEC_12_10_0
 void zxipcf_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 void xszcrd_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void msldst_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xszvab_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -300,7 +304,7 @@ void xscomptb(const double* energy, int nFlux, const double* params, int spectru
 void nsmaxg_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void nsx_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
-  
+
 //multiplicative
 void xsphei_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 void xslyman_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
@@ -312,13 +316,28 @@ void ismabs_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 void slimbbmodel(const double* energy, int nFlux, const double* params, int spectrumNumber, double* flux, double* fluxError, const char* initStr);
 #endif
 
+#ifdef XSPEC_12_11_0
+void ismdust_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
+void olivineabs_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
+
+// Note: have dropped the leading 'c_' for this model
+// TODO: should look at whether we want to fix this as now have a
+//       number of c_xxx functions in model.dat
+void beckerwolff(const double* energy, int nFlux, const double* params, int spectrumNumber, double* flux, double* fluxError, const char* initStr);
+#endif
+
+
 // XSPEC table models; in XSPEC 12.10.1 these have been consolidated
-// into the tabint routine.
+// into the tabint routine, but that is only available to C++, and
+// so is defined in sherpa/include/sherpa/astro/xspec_extension.hh
+// In XSPEC 12.11.0 tabint is available in C scope (but is again
+// defined in xspec_extension.hh as it doesn't need to be visible
+// here).
 //
 #ifndef XSPEC_12_10_1
-void xsatbl(float* ear, int ne, float* param, const char* filenm, int ifl, 
+void xsatbl(float* ear, int ne, float* param, const char* filenm, int ifl,
 	    float* photar, float* photer);
-void xsmtbl(float* ear, int ne, float* param, const char* filenm, int ifl, 
+void xsmtbl(float* ear, int ne, float* param, const char* filenm, int ifl,
 	    float* photar, float* photer);
 #endif
 
@@ -331,6 +350,10 @@ void rgsxsrc_(float* ear, int* ne, float* param, int* ifl, float* photar, float*
 void kyconv_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
 #endif
 
+#ifdef XSPEC_12_11_0
+void thcompf_(float* ear, int* ne, float* param, int* ifl, float* photar, float* photer);
+#endif
+
 }
 
 // This routine could be called when the module is being initialized,
@@ -355,7 +378,7 @@ int _sherpa_init_xspec_library()
 		     "HEADAS environment variable is not set" );
     return EXIT_FAILURE;
   }
-  
+
   // Stream buffer for redirected stdout
   std::streambuf* cout_sbuf = NULL;
   std::ofstream fout;
@@ -379,7 +402,7 @@ int _sherpa_init_xspec_library()
 
     // Note:  since we are *not* redirecting std::cerr, any error
     // messages are still seen; if, for example, HEADAS is not set,
-    // user will still see error message printed to stderr (i.e., to 
+    // user will still see error message printed to stderr (i.e., to
     // screen by default).  We still want such error messages to be
     // seen!  So do *not* redirect std::cerr.
     //
@@ -389,23 +412,23 @@ int _sherpa_init_xspec_library()
     // Perhaps the screen output could be saved, rather than redirected
     // to /dev/null, and checked for the string '***Error: ', which
     // appears to be used in the error messages from XSPEC.
-    
+
     cout_sbuf = std::cout.rdbuf();
     fout.open("/dev/null");
     if (cout_sbuf != NULL && fout.is_open())
       std::cout.rdbuf(fout.rdbuf()); // temporary redirect stdout to /dev/null
-    
+
     // Initialize XSPEC model library
     FNINIT();
-    
+
     // Get back original std::cout
     if (cout_sbuf != NULL) {
       std::cout.clear();
-      std::cout.rdbuf(cout_sbuf); 
+      std::cout.rdbuf(cout_sbuf);
     }
     fout.clear();
     fout.close();
-    
+
     // Try to minimize model chatter for normal operation.
     FPCHAT( 0 );
 
@@ -450,7 +473,7 @@ int _sherpa_init_xspec_library()
 }
 
 static PyObject* get_version( PyObject *self )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -459,7 +482,7 @@ static PyObject* get_version( PyObject *self )
   int retval;
 
   try {
-    
+
     retval = xs_getVersion(version, 256);
 
   } catch(...) {
@@ -469,19 +492,19 @@ static PyObject* get_version( PyObject *self )
     return NULL;
 
   }
-  
+
   if( retval < 0 ) {
     PyErr_SetString( PyExc_LookupError,
 		     (char*)"XSPEC version string was truncated" );
     return NULL;
   }
-  
+
   return Py_BuildValue( (char*)"s", version );
 
 }
 
 static PyObject* get_chatter( PyObject *self )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -506,7 +529,7 @@ static PyObject* get_chatter( PyObject *self )
 
 
 static PyObject* get_abund( PyObject *self, PyObject *args )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -533,46 +556,46 @@ static PyObject* get_abund( PyObject *self, PyObject *args )
   if( !element ) {
 
     retval = (PyObject*) Py_BuildValue( (char*)"s", abund );
-  
+
   } else {
 
     float abundVal = 0.0;
     std::streambuf *cerr_sbuf = NULL;
     std::ostringstream fout;
-    
+
     try {
-      
+
       cerr_sbuf = std::cerr.rdbuf();
-      
+
       if (cerr_sbuf != NULL)
 	std::cerr.rdbuf(fout.rdbuf());
-      
+
       abundVal = FGABND(element);
-      
-      // Get back original std::cerr
-      if (cerr_sbuf != NULL)
-	std::cerr.rdbuf(cerr_sbuf); 
-      
-      
-    } catch(...) {
-      
+
       // Get back original std::cerr
       if (cerr_sbuf != NULL)
 	std::cerr.rdbuf(cerr_sbuf);
-      
+
+
+    } catch(...) {
+
+      // Get back original std::cerr
+      if (cerr_sbuf != NULL)
+	std::cerr.rdbuf(cerr_sbuf);
+
       PyErr_Format( PyExc_ValueError,
 		    (char*)"could not get XSPEC abundance for '%s'",
 		  element);
       return NULL;
-      
+
     }
-    
+
     if( fout.str().size() > 0 ) {
       PyErr_Format( PyExc_TypeError,
 		    (char*)"could not find element '%s'", element);
       return NULL;
     }
-    
+
     retval = (PyObject*) Py_BuildValue( (char*)"f", abundVal );
   }
 
@@ -581,7 +604,7 @@ static PyObject* get_abund( PyObject *self, PyObject *args )
 
 
 static PyObject* get_cosmo( PyObject *self )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -610,7 +633,7 @@ static PyObject* get_cosmo( PyObject *self )
 
 
 static PyObject* get_cross( PyObject *self )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -635,7 +658,7 @@ static PyObject* get_cross( PyObject *self )
 
 
 static PyObject* set_chatter( PyObject *self, PyObject *args )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -650,7 +673,7 @@ static PyObject* set_chatter( PyObject *self, PyObject *args )
     FPCHAT( chatter );
 
   } catch(...) {
-    
+
     PyErr_Format( PyExc_ValueError,
                   (char*)"could not set XSPEC chatter level to %d",
                   chatter);
@@ -664,7 +687,7 @@ static PyObject* set_chatter( PyObject *self, PyObject *args )
 
 
 static PyObject* set_abund( PyObject *self, PyObject *args )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -680,7 +703,7 @@ static PyObject* set_abund( PyObject *self, PyObject *args )
     FPSOLR( table, &status );
 
   } catch(...) {
-    
+
     status = 1;
 
   }
@@ -693,38 +716,38 @@ static PyObject* set_abund( PyObject *self, PyObject *args )
     size_t count(0);
 
     try {
-      
+
       float element;
       fileStream.exceptions(std::ios_base::failbit);
-      
+
       while (count < ABUND_SIZE && fileStream >> element) {
 	vals[count] = element;
 	++count;
       }
-      
+
       status = 0;
     }
     catch ( std::exception& ) {
-     
+
       if( !fileStream.eof() ) {
-      	PyErr_Format( PyExc_ValueError, 
+      	PyErr_Format( PyExc_ValueError,
                       (char*)"Cannot read file '%s'.  It may not exist or contains invalid data",
                       table);
 	return NULL;
       }
-      
+
       status = 1;
     }
 
     try {
-      
+
       FPSOLR((char*)"file", &status);
       FPSLFL( &vals[0], ABUND_SIZE, &status );
-      
+
     } catch(...) {
-      
+
       status = 1;
-      
+
     }
   }
 
@@ -741,7 +764,7 @@ static PyObject* set_abund( PyObject *self, PyObject *args )
 
 
 static PyObject* set_cosmo( PyObject *self, PyObject *args )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -775,7 +798,7 @@ static PyObject* set_cosmo( PyObject *self, PyObject *args )
 
 
 static PyObject* set_cross( PyObject *self, PyObject *args )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -810,7 +833,7 @@ static PyObject* set_cross( PyObject *self, PyObject *args )
 
 
 static PyObject* set_xset( PyObject *self, PyObject *args )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -844,7 +867,7 @@ static PyObject* set_xset( PyObject *self, PyObject *args )
 }
 
 static PyObject* get_xset( PyObject *self, PyObject *args  )
-{ 
+{
 
   if ( EXIT_SUCCESS != _sherpa_init_xspec_library() )
     return NULL;
@@ -959,6 +982,10 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_NORM( qsosed, 7 ),
 #endif
 
+#ifdef XSPEC_12_11_0
+  XSPECMODELFCT_NORM( agnslim, 15 ),
+#endif
+
 #ifdef XSPEC_12_9_1
   XSPECMODELFCT_C_NORM( C_apec, 4 ),
   XSPECMODELFCT_C_NORM( C_bapec, 5 ),
@@ -980,7 +1007,7 @@ static PyMethodDef XSpecMethods[] = {
 #endif
 #ifdef XSPEC_12_9_1
   XSPECMODELFCT_C_NORM( C_bvapec, 17 ),
-#else  
+#else
   XSPECMODELFCT_NORM( xsbvpe, 17 ),
 #endif
 #ifdef XSPEC_12_10_0
@@ -989,12 +1016,12 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_C_NORM( C_c6pmekl, 11 ),
   XSPECMODELFCT_C_NORM( C_c6pvmkl, 24 ),
   XSPECMODELFCT_C_NORM( C_c6vmekl, 24 ),
-#else  
+#else
   XSPECMODELFCT_NORM( c6mekl, 11 ),
   XSPECMODELFCT_NORM( c6pmekl, 11 ),
   XSPECMODELFCT_NORM( c6pvmkl, 24 ),
   XSPECMODELFCT_NORM( c6vmekl, 24 ),
-#endif  
+#endif
   XSPECMODELFCT_NORM( cemekl, 7 ),
   XSPECMODELFCT_C_NORM( C_cemVMekal, 20 ),
   XSPECMODELFCT_C_NORM( C_xscflw, 6 ),
@@ -1026,11 +1053,16 @@ static PyMethodDef XSpecMethods[] = {
 #endif
   XSPECMODELFCT_C_NORM( C_gnei, 6 ),
   XSPECMODELFCT_NORM( grad, 7 ),
-#ifdef XSPEC_12_10_0  
+#ifdef XSPEC_12_10_0
   XSPECMODELFCT_C_NORM( xsgrbcomp, 10 ),
-#endif  
+#endif
   XSPECMODELFCT_NORM( xsgrbm, 4 ),
   XSPECMODELFCT_C_NORM( C_kerrbb, 10 ),
+
+#ifdef XSPEC_12_11_0
+  XSPECMODELFCT_C_NORM( C_zkerrbb, 10 ),
+#endif
+
 #ifdef XSPEC_12_10_0
   /* From an email from Craig Gordon at HEASARC:
      12.10.0 and later: for kerrd call C_kerrd. For earlier versions kerrd should call C_kerrdisk.
@@ -1060,7 +1092,7 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_NORM( xslorz, 3 ),
   XSPECMODELFCT_NORM( xsmeka, 5 ),
   XSPECMODELFCT_NORM( xsmekl, 6 ),
-#endif  
+#endif
   XSPECMODELFCT_C_NORM( C_xsmkcf, 6 ),
   XSPECMODELFCT_C_NORM( C_nei, 5 ),
   XSPECMODELFCT_C_NORM( C_nlapec, 4 ),
@@ -1068,7 +1100,7 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_NORM( nsa, 5 ),
   XSPECMODELFCT_NORM( nsagrav, 4 ),
   XSPECMODELFCT_NORM( nsatmos, 5 ),
-#ifdef XSPEC_12_10_0  
+#ifdef XSPEC_12_10_0
   XSPECMODELFCT_C_NORM( C_nsmax, 4 ),
 #else
   XSPECMODELFCT_NORM( nsmax, 4 ),
@@ -1086,23 +1118,23 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_C_NORM(C_raysmith, 4 ),
 #else
   XSPECMODELFCT_NORM( xsrays, 4 ),
-#endif  
+#endif
   XSPECMODELFCT_NORM( xredge, 3 ),
   XSPECMODELFCT_NORM( xsrefsch, 14 ),
 
   XSPECMODELFCT_C_NORM( C_sedov, 6 ),
   XSPECMODELFCT_NORM( srcut, 3 ),
   XSPECMODELFCT_NORM( sresc, 3 ),
-#ifdef XSPEC_12_10_0  
+#ifdef XSPEC_12_10_0
   XSPECMODELFCT_NORM( ssa, 3 ),
-#endif  
+#endif
   XSPECMODELFCT_NORM( xsstep, 3 ),
 
 #ifdef XSPEC_12_9_1
   XSPECMODELFCT_C_NORM( C_vapec, 16 ),
-#else  
+#else
   XSPECMODELFCT_NORM( xsvape, 16 ),
-#endif  
+#endif
   XSPECMODELFCT_NORM( xsbrmv, 3 ),
 
 #ifdef XSPEC_12_10_1
@@ -1117,7 +1149,7 @@ static PyMethodDef XSpecMethods[] = {
 #else
   XSPECMODELFCT_NORM( xsvmek, 18 ),
   XSPECMODELFCT_NORM( xsvmkl, 19 ),
-#endif  
+#endif
   XSPECMODELFCT_C_NORM( C_xsvmcf, 19 ),
   XSPECMODELFCT_C_NORM( C_vnei, 17 ),
   XSPECMODELFCT_C_NORM( C_vnpshock, 19 ),
@@ -1126,7 +1158,7 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_C_NORM( C_vraysmith, 15 ),
 #else
   XSPECMODELFCT_NORM( xsvrys, 15 ),
-#endif  
+#endif
   XSPECMODELFCT_C_NORM( C_vsedov, 18 ),
   XSPECMODELFCT_NORM( xszbod, 3 ),
 
@@ -1152,7 +1184,7 @@ static PyMethodDef XSpecMethods[] = {
 #else
   XSPECMODELFCT( acisabs, 8 ),
 #endif
-  
+
   XSPECMODELFCT( xscnst, 1 ),
   XSPECMODELFCT( xscabs, 1 ),
   XSPECMODELFCT( xscycl, 5 ),
@@ -1174,12 +1206,12 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT( xsspln, 6 ),
   XSPECMODELFCT( xssssi, 1 ),
 
-#ifdef XSPEC_12_10_0  
+#ifdef XSPEC_12_10_0
   XSPECMODELFCT_C( C_swind1, 4 ),
 #else
   XSPECMODELFCT( swind1, 4 ),
 #endif
-  
+
   XSPECMODELFCT_C( C_tbabs, 1 ),
   XSPECMODELFCT_C( C_tbgrain, 6 ),
   XSPECMODELFCT_C( C_tbvabs, 42 ),
@@ -1200,7 +1232,7 @@ static PyMethodDef XSpecMethods[] = {
 #else
   XSPECMODELFCT( zxipcf, 4 ),
 #endif
-  
+
   XSPECMODELFCT( xszcrd, 2 ),
   XSPECMODELFCT( msldst, 4 ),
   XSPECMODELFCT_C( C_ztbabs, 2 ),
@@ -1221,7 +1253,7 @@ static PyMethodDef XSpecMethods[] = {
 #ifdef XSPEC_12_9_1
   XSPECMODELFCT_C_NORM( C_bvvapec, 34 ),
   XSPECMODELFCT_C_NORM( C_vvapec, 33 ),
-#else  
+#else
   XSPECMODELFCT_NORM( xsbvvp, 34 ),
   XSPECMODELFCT_NORM( xsvvap, 33 ),
 #endif
@@ -1235,9 +1267,9 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_NORM( eplogpar, 3 ),
 #ifdef XSPEC_12_10_1
   XSPECMODELFCT_C_NORM( C_logpar, 4 ),
-#else  
+#else
   XSPECMODELFCT_NORM( logpar, 4 ),
-#endif  
+#endif
   XSPECMODELFCT_NORM( optxagn, 14 ),
   XSPECMODELFCT_NORM( optxagnf, 12 ),
   XSPECMODELFCT_NORM( pexmon, 8 ),
@@ -1250,14 +1282,14 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_C_NORM( xscompmag, 9 ), // DJB thinks it's okay to use the C++ wrapper for C
   XSPECMODELFCT_C_NORM( xscomptb, 7 ), // DJB thinks it's okay to use the C++ wrapper for C
 
-#ifdef XSPEC_12_10_0  
+#ifdef XSPEC_12_10_0
   XSPECMODELFCT_C_NORM( C_nsmaxg, 6 ),
   XSPECMODELFCT_C_NORM( C_nsx, 6 ),
 #else
   XSPECMODELFCT_NORM( nsmaxg, 6 ),
   XSPECMODELFCT_NORM( nsx, 6 ),
 #endif
-  
+
   XSPECMODELFCT_C_NORM( C_rnei, 6 ),
   XSPECMODELFCT_C_NORM( C_vrnei, 18 ),
   XSPECMODELFCT_C_NORM( C_vvrnei, 35 ),
@@ -1267,6 +1299,14 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_C_NORM( C_vvpshock, 35 ),
   XSPECMODELFCT_C_NORM( C_vvsedov, 35 ),
 
+#ifdef XSPEC_12_11_0
+  // We do not have a direct interface to the c_func routines, so
+  // take advantage of the fact XSPEC provides multiple APIs
+  // and use the C one.
+  // XSPECMODELFCT_C_NORM( c_beckerwolff, 13 ),
+  XSPECMODELFCT_C_NORM( beckerwolff, 13 ),
+#endif
+
   //multiplicative
   XSPECMODELFCT( xsphei, 3 ),
   XSPECMODELFCT( xslyman, 4 ),
@@ -1284,12 +1324,12 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_CON(C_cflux, 3),
   XSPECMODELFCT_CON(C_cpflux, 3),
 
-#ifdef XSPEC_12_10_0  
+#ifdef XSPEC_12_10_0
   XSPECMODELFCT_CON(C_gsmooth, 2),
 #else
   XSPECMODELFCT_CON(C_xsgsmt, 2),
 #endif
-  
+
   XSPECMODELFCT_CON(C_ireflct, 7),
   XSPECMODELFCT_CON(C_kdblur, 4),
   XSPECMODELFCT_CON(C_kdblur2, 6),
@@ -1299,12 +1339,12 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_CON_F77(kyconv, 12),
 #endif
 
-#ifdef XSPEC_12_10_0  
+#ifdef XSPEC_12_10_0
   XSPECMODELFCT_CON(C_lsmooth, 2),
 #else
   XSPECMODELFCT_CON(C_xslsmt, 2),
 #endif
-  
+
   XSPECMODELFCT_CON(C_PartialCovering, 1),
   XSPECMODELFCT_CON(C_rdblur, 4),
   XSPECMODELFCT_CON(C_reflct, 5),
@@ -1314,6 +1354,10 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_CON(C_zashift, 1),
   XSPECMODELFCT_CON(C_zmshift, 1),
 
+#ifdef XSPEC_12_11_0
+  XSPECMODELFCT_CON_F77(thcompf, 4),
+#endif
+
   // Models from 12.9.1
   //
   //
@@ -1327,10 +1371,8 @@ static PyMethodDef XSpecMethods[] = {
 
   XSPECMODELFCT_C_NORM(C_carbatm, 4),
   XSPECMODELFCT_C_NORM(C_hatm, 4),
-#ifdef XSPEC_12_10_0  
-  XSPECMODELFCT_NORM(jet, 16),
-#endif
   XSPECMODELFCT(ismabs, 31),
+
   XSPECMODELFCT_C_NORM(slimbbmodel, 10),
   XSPECMODELFCT_C_NORM(C_snapec, 7),
   XSPECMODELFCT_C(C_tbfeo, 4),
@@ -1347,6 +1389,17 @@ static PyMethodDef XSpecMethods[] = {
   XSPECMODELFCT_CON(C_xilconv, 6),
   #endif
 
+#ifdef XSPEC_12_10_0
+  XSPECMODELFCT_NORM(jet, 16),
+#endif
+
+#ifdef XSPEC_12_11_0
+  XSPECMODELFCT(ismdust, 3),
+  XSPECMODELFCT(olivineabs, 2),
+  XSPECMODELFCT_C(C_logconst, 1),
+  XSPECMODELFCT_C(C_log10con, 1),
+#endif
+
   { NULL, NULL, 0, NULL }
 
 };
